@@ -6,11 +6,10 @@ from .Refund import Refund
 
 
 class DecidirSDK:
-    def __init__(self, merchant, merchant_cadena=None):
+    def __init__(self, merchant, merchant_cadena=None,site_id=None):
         if merchant_cadena:
             credentials = merchant_cadena['credentials']['decidir']
             self.payment_type = 'distributed'
-            self.seller_site_id = merchant['credentials']['decidir']['site_id']
         else:
             credentials = merchant['credentials']['decidir']
             self.payment_type = 'single'
@@ -19,7 +18,7 @@ class DecidirSDK:
         self.public_key = credentials['public_key']
         self.merchant_id = merchant['_id']
         self.merchant_name = merchant['name']
-        self.site_id = credentials['site_id']
+        self.site_id = site_id
 
     def customer(self):
         return Customer(self.url, self.private_key, self.public_key)
